@@ -1,6 +1,6 @@
 use ecs_rust::world::World;
+use ecs_rust::entity_manager::EntityManager;
 use ecs_rust::component::Component;
-use ecs_rust::component_manager::ComponentsManager;
 use ecs_rust::system::System;
 
 struct Person {
@@ -13,7 +13,7 @@ impl Component for Person {
 }
 
 impl System for HelloSystem {
-	fn update(&mut self, manager: &mut ComponentsManager) {
+	fn update(&mut self, manager: &mut EntityManager) {
 		let people = manager.borrow_components::<Person>().unwrap();
 		for p in people.iter() {
 			println!("Hello {}", p.name);
