@@ -1,11 +1,9 @@
 use super::entity_manager::EntityManager;
 use super::component::Component;
-use super::component_manager::ComponentsManager;
 use super::system::System;
 
 pub struct World {
 	entity_manager: EntityManager,
-	components_manager: ComponentsManager,
 	systems: Vec<Box<dyn System>>
 }
 
@@ -13,17 +11,16 @@ impl World {
 	pub fn new() -> Self {
 		World {
 			entity_manager: EntityManager::new(),
-			systems: vec![],
-			components_manager: ComponentsManager::new()
+			systems: vec![]
 		}
 	}
 
 	pub fn create_entity(&mut self) -> usize {
-		self.entity_manager.create()
+		self.entity_manager.create_entity()
 	}
 
 	pub fn register_component<T: 'static + Component>(&mut self) -> &mut Self {
-		self.components_manager.register::<T>();
+		self.entity_manager.register::<T>();
 		self
 	}
 
@@ -33,13 +30,13 @@ impl World {
 	}
 
 	pub fn add_component_to_entity<T: 'static + Component>(&mut self, entity_id: usize, component: T) -> &mut Self {
-		self.components_manager.add_component_to_entity(entity_id, component);
+		self.entity_manager.add_component_to_entity(entity_id, component);
 		self
 	}
 
 	pub fn update(&mut self) {
 		for system in self.systems.iter_mut() {
-			system.update(&mut self.components_manager);
+			system.update(&mut self.entity_manager);
 		}
 	}
 }
